`xotl.tools.infinity`:mod: - An infinite value
==============================================

.. module:: xotl.tools.infinity

.. data:: Infinity

   The positive infinite value.  The negative infinite value is ``-Infinity``.

   These values are only sensible for comparison.  Arithmetic is not
   supported.

   The type of values that is comparable with `Infinity`:obj: is controlled by
   the ABC `InfinityComparable`:class:.


.. autoclass:: InfinityComparable
